package xyz.ottr.spec.wottr;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

import org.apache.jena.rdf.model.Model;
import org.apache.jena.rdf.model.Resource;

import picocli.CommandLine;
import picocli.CommandLine.Option;
import picocli.CommandLine.Parameters;

public class PrintTable {

	private final static String reportFolder = "reports/";
	private final static String reportFilename = "report.ttl";
	
	@Option(names="-s", required = true)
	private String[] shapesFiles;
	
	@Parameters
	private List<String> dataFiles = new ArrayList<>();
	
	@Option(names="-f", arity="1")
	private String folder = "";
	
	@Option(names="-b")
	private String[] backgroundDataFiles;
	
	public static void main(String[] args) throws IOException {
		PrintTable tar = new PrintTable();
		new CommandLine(tar).parse(args);
		tar.run();
	}
	
    public void run() throws IOException  {
    	if (!folder.isEmpty()) {
    		dataFiles.addAll(Util.getFiles(folder));
    	}
    	
		Model shape = Util.getModel(shapesFiles);
		Model dataBackground = Util.getModel(backgroundDataFiles);
		
		String table = "<table>";
		table += "<tr><th>Result</th><th>Data</th><th>Shape<th>Report</th></tr>";
		for (String url : dataFiles) {			
			Model data = Util.getModel(url).add(dataBackground);
			Resource report = Util.getReport(shape, data);
			boolean isConforms = Util.isConforms(report);
			writeReport(url, report);
			table += printTableRow(shapesFiles, url, isConforms);		
			}
		table += "</table>";
		System.out.println(table);
    }

	private  void writeReport(String dataURL, Resource report) throws FileNotFoundException {
		String folder = Util.ROOT + reportFolder + (dataURL) + "/";
		new File(folder).mkdirs();
		Util.writeModel(report.getModel(), folder + reportFilename);
	}

	private String printTableRow (String[] shapes, String data, boolean result) {
		String text = "<tr class=\"" + result + "\">";
		text += "<td>" + result + "</td>";
		text += "<td><a href=\"" + data + "\">" + data + "</a></td>";
		text += "<td>";
		for (String shape : shapes) { 
			String shapeURL = (shape);
			text += "<a href=\"" + shapeURL + "\">" + shapeURL + "</a>  ";
		}
		text += "</td>";
		text += "<td><a href=\"" + reportFolder + data + "/" + reportFilename + "\">report</td>";
		text += "</tr>";
		return text;
	}
}

