package xyz.ottr.spec.wottr;

import static org.junit.Assert.assertEquals;
import java.io.*;
import java.util.*;
import java.util.stream.Collectors;
import org.apache.jena.rdf.model.Model;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;
import org.junit.runners.Parameterized.Parameters;

@RunWith(Parameterized.class)
public class SHACLConformTest {

	private String file;
	private boolean shouldConform;
	
	public SHACLConformTest(String file, boolean shouldConform) {
		this.file = file;
		this.shouldConform = shouldConform;
	}

	@Parameters(name = "{index}: {0}")
	public static Collection<Object[]> collectInput () throws IOException {
		List<String> files = Util.getFiles("examples");
		files.addAll(Util.getFiles("tests/correct"));
		files.addAll(Util.getFiles("tests/incorrect"));
		
		return files.stream()
				.map(file -> new Object[] { file, !file.startsWith("tests/incorrect") }) // incorrect-s should not conform
				.collect(Collectors.toList());
	}

	@Test
	public void test() throws FileNotFoundException {
		Model shapeModel = Util.getModel(Util.GRAMMAR, Util.TYPES, Util.STD_TOKENS, Util.TOKENS);
		Model dataModel = Util.getModel(file, Util.VOCABULARY);
		boolean conforms = Util.isConforms(Util.getReport(shapeModel, dataModel));
		assertEquals(shouldConform, conforms);
	}
}